@@ -1,6 +1,4 @@
 use std::error::Error;
-use std::fs;
-use std::path::Path;
 
 use heed::types::*;
 use heed::{Database, EnvOpenOptions, PutFlags};
@@ -8,11 +6,8 @@ use heed::{Database, EnvOpenOptions, PutFlags};
 // In this test we are checking that we can append ordered entries in one
 // database even if there is multiple databases which already contain entries.
 fn main() -> Result<(), Box<dyn Error>> {
-    let env_path = Path::new("target").join("cursor-append.mdb");
+    let env_path = tempfile::tempdir()?;
 
-    let _ = fs::remove_dir_all(&env_path);
-
-    fs::create_dir_all(&env_path)?;
     let env = unsafe {
         EnvOpenOptions::new()
             .map_size(10 * 1024 * 1024) // 10MB
