@@ -1,15 +1,11 @@
 use std::error::Error;
-use std::fs;
-use std::path::Path;
 
 use heed::types::{SerdeRmp, Str};
 use heed::{Database, EnvOpenOptions};
 use serde::{Deserialize, Serialize};
 
 fn main() -> Result<(), Box<dyn Error>> {
-    let path = Path::new("target").join("heed.mdb");
-
-    fs::create_dir_all(&path)?;
+    let path = tempfile::tempdir()?;
 
     let env = unsafe {
         EnvOpenOptions::new()
