@@ -5,6 +5,8 @@
 //! - [Create Custom and Prefix Codecs](#create-custom-and-prefix-codecs)
 //! - [Change the Environment Size Dynamically](#change-the-environment-size-dynamically)
 //! - [Advanced Multithreaded Access of Entries](#advanced-multithreaded-access-of-entries)
+//! - [Use Custom Key Comparator](#use-custom-key-comparator)
+//! - [Use Custom Dupsort Comparator](#use-custom-dupsort-comparator)
 //!
 //! # Decode Values on Demand
 //!
@@ -24,9 +26,7 @@
 //! pub type StringMap = HashMap<String, String>;
 //!
 //! fn main() -> Result<(), Box<dyn Error + Send + Sync>> {
-//!     let path = Path::new("target").join("heed.mdb");
-//!
-//!     fs::create_dir_all(&path)?;
+//!     let path = tempfile::tempdir()?;
 //!
 //!     let env = unsafe {
 //!         EnvOpenOptions::new()
@@ -92,9 +92,7 @@
 //! use heed::{Database, EnvOpenOptions};
 //!
 //! fn main() -> Result<(), Box<dyn Error>> {
-//!     let env_path = Path::new("target").join("heed.mdb");
-//!
-//!     fs::create_dir_all(&env_path)?;
+//!     let env_path = tempfile::tempdir()?;
 //!
 //!     let env = unsafe {
 //!         EnvOpenOptions::new()
@@ -233,9 +231,7 @@
 //! }
 //!
 //! fn main() -> Result<(), Box<dyn Error>> {
-//!     let path = Path::new("target").join("heed.mdb");
-//!
-//!     fs::create_dir_all(&path)?;
+//!     let path = tempfile::tempdir()?;
 //!
 //!     let env = unsafe {
 //!         EnvOpenOptions::new()
@@ -298,9 +294,7 @@
 //! use heed::{Database, EnvOpenOptions};
 //!
 //! fn main() -> Result<(), Box<dyn Error>> {
-//!     let path = Path::new("target").join("small-space.mdb");
-//!
-//!     fs::create_dir_all(&path)?;
+//!     let path = tempfile::tempdir()?;
 //!
 //!     let env = unsafe {
 //!         EnvOpenOptions::new()
@@ -349,8 +343,14 @@
 //!
 //! # Advanced Multithreaded Access of Entries
 //!
-//! LMDB disallow sharing cursors amongs threads. It is only possible to send
-//! them between threads when the heed `read-txn-no-tls` feature is enabled.
+//! LMDB disallows sharing cursors among threads. It is only possible to send
+//! them between threads when the environment has been opened with
+//! [`EnvOpenOptions::read_txn_without_tls`] method.
+//!
+//! Please note that this should not be utilized with an encrypted heed3 database. These
+//! types of databases employ an internal cycling buffer for decrypting entries, which
+//! may result in reading keys that invalidate previous ones. In essence, the use of
+//! the `EncryptedDatabase` signature prevents this scenario.
 //!
 //! This limits some usecases that require a parallel access to the content of the databases
 //! to process stuff faster. This is the case of arroy, a multithreads fast approximate
@@ -377,9 +377,7 @@
 //! use heed::{Database, EnvOpenOptions, RoTxn};
 //!
 //! fn main() -> Result<(), Box<dyn Error + Send + Sync>> {
-//!     let path = Path::new("target").join("heed.mdb");
-//!
-//!     fs::create_dir_all(&path)?;
+//!     let path = tempfile::tempdir()?;
 //!
 //!     let env = unsafe {
 //!         EnvOpenOptions::new()
@@ -445,8 +443,146 @@
 //! unsafe impl Sync for ImmutableMap<'_> {}
 //! ```
 //!
+//! # Use Custom Key Comparator
+//!
+//! LMDB keys are sorted in lexicographic order by default. To change this behavior
+//! you can implement a custom [`Comparator`] and provide it when creating the database.
+//!
+//! Under the hood this translates into a [`mdb_set_compare`] call.
+//!
+//! ```
+//! use std::cmp::Ordering;
+//! use std::error::Error;
+//! use std::str;
+//!
+//! use heed::EnvOpenOptions;
+//! use heed_traits::Comparator;
+//! use heed_types::{Str, Unit};
+//!
+//! enum StringAsIntCmp {}
+//!
+//! // This function takes two strings which represent integers,
+//! // parses them into i32s and compare the parsed value.
+//! // Therefore "-1000" < "-100" must be true even without '0' padding.
+//! impl Comparator for StringAsIntCmp {
+//!     fn compare(a: &[u8], b: &[u8]) -> Ordering {
+//!         let a: i32 = str::from_utf8(a).unwrap().parse().unwrap();
+//!         let b: i32 = str::from_utf8(b).unwrap().parse().unwrap();
+//!         a.cmp(&b)
+//!     }
+//! }
+//!
+//! fn main() -> Result<(), Box<dyn Error>> {
+//!     let path = tempfile::tempdir()?;
+//!
+//!     let env = unsafe {
+//!         EnvOpenOptions::new()
+//!             .map_size(10 * 1024 * 1024) // 10MB
+//!             .max_dbs(3)
+//!             .open(path)?
+//!     };
+//!
+//!     let mut wtxn = env.write_txn()?;
+//!     let db = env
+//!         .database_options()
+//!         .types::<Str, Unit>()
+//!         .key_comparator::<StringAsIntCmp>()
+//!         .create(&mut wtxn)?;
+//!     wtxn.commit()?;
+//!
+//!     let mut wtxn = env.write_txn()?;
+//!
+//!     // We fill our database with entries.
+//!     db.put(&mut wtxn, "-100000", &())?;
+//!     db.put(&mut wtxn, "-10000", &())?;
+//!     db.put(&mut wtxn, "-1000", &())?;
+//!     db.put(&mut wtxn, "-100", &())?;
+//!     db.put(&mut wtxn, "100", &())?;
+//!
+//!     // We check that the key are in the right order ("-100" < "-1000" < "-10000"...)
+//!     let mut iter = db.iter(&wtxn)?;
+//!     assert_eq!(iter.next().transpose()?, Some(("-100000", ())));
+//!     assert_eq!(iter.next().transpose()?, Some(("-10000", ())));
+//!     assert_eq!(iter.next().transpose()?, Some(("-1000", ())));
+//!     assert_eq!(iter.next().transpose()?, Some(("-100", ())));
+//!     assert_eq!(iter.next().transpose()?, Some(("100", ())));
+//!     drop(iter);
+//!
+//!     Ok(())
+//! }
+//! ```
+//!
+//! # Use Custom Dupsort Comparator
+//!
+//! When using DUPSORT LMDB sorts values of the same key in lexicographic order by default.
+//! To change this behavior you can implement a custom [`Comparator`] and provide it when
+//! creating the database.
+//!
+//! Under the hood this translates into a [`mdb_set_dupsort`] call.
+//!
+//! ```
+//! use std::cmp::Ordering;
+//! use std::error::Error;
+//!
+//! use byteorder::BigEndian;
+//! use heed::{DatabaseFlags, EnvOpenOptions};
+//! use heed_traits::Comparator;
+//! use heed_types::{Str, U128};
+//!
+//! enum DescendingIntCmp {}
+//!
+//! impl Comparator for DescendingIntCmp {
+//!     fn compare(a: &[u8], b: &[u8]) -> Ordering {
+//!         a.cmp(&b).reverse()
+//!     }
+//! }
+//!
+//! fn main() -> Result<(), Box<dyn Error>> {
+//!     let path = tempfile::tempdir()?;
+//!
+//!     let env = unsafe {
+//!         EnvOpenOptions::new()
+//!             .map_size(10 * 1024 * 1024) // 10MB
+//!             .max_dbs(3)
+//!             .open(path)?
+//!     };
+//!
+//!     let mut wtxn = env.write_txn()?;
+//!     let db = env
+//!         .database_options()
+//!         .types::<Str, U128<BigEndian>>()
+//!         .flags(DatabaseFlags::DUP_SORT)
+//!         .dup_sort_comparator::<DescendingIntCmp>()
+//!         .create(&mut wtxn)?;
+//!     wtxn.commit()?;
+//!
+//!     let mut wtxn = env.write_txn()?;
+//!
+//!     // We fill our database with entries.
+//!     db.put(&mut wtxn, "1", &1)?;
+//!     db.put(&mut wtxn, "1", &2)?;
+//!     db.put(&mut wtxn, "1", &3)?;
+//!     db.put(&mut wtxn, "2", &4)?;
+//!     db.put(&mut wtxn, "1", &5)?;
+//!     db.put(&mut wtxn, "0", &0)?;
+//!
+//!     // We check that the keys are in lexicographic and values in descending order.
+//!     let mut iter = db.iter(&wtxn)?;
+//!     assert_eq!(iter.next().transpose()?, Some(("0", 0)));
+//!     assert_eq!(iter.next().transpose()?, Some(("1", 5)));
+//!     assert_eq!(iter.next().transpose()?, Some(("1", 3)));
+//!     assert_eq!(iter.next().transpose()?, Some(("1", 2)));
+//!     assert_eq!(iter.next().transpose()?, Some(("1", 1)));
+//!     assert_eq!(iter.next().transpose()?, Some(("2", 4)));
+//!     drop(iter);
+//!
+//!     Ok(())
+//! }
+//! ```
+//!
 
 // To let cargo generate doc links
 #![allow(unused_imports)]
 
-use crate::{BytesDecode, BytesEncode, Database, EnvOpenOptions};
+use crate::mdb::ffi::{mdb_set_compare, mdb_set_dupsort};
+use crate::{BytesDecode, BytesEncode, Comparator, Database, EnvOpenOptions};
