@@ -5,7 +5,7 @@ use heed_traits::LexicographicComparator;
 use types::LazyDecode;
 
 use crate::cursor::MoveOperation;
-use crate::env::DefaultComparator;
+use crate::envs::DefaultComparator;
 use crate::iteration_method::{IterationMethod, MoveBetweenKeys, MoveThroughDuplicateValues};
 use crate::*;
 
@@ -200,9 +200,6 @@ impl<KC, DC, C, IM> fmt::Debug for RoPrefix<'_, KC, DC, C, IM> {
     }
 }
 
-#[cfg(feature = "read-txn-no-tls")]
-unsafe impl<KC, DC, IM> Send for RoPrefix<'_, KC, DC, IM> {}
-
 /// A read-write prefix iterator structure.
 pub struct RwPrefix<'txn, KC, DC, C = DefaultComparator, IM = MoveThroughDuplicateValues> {
     cursor: RwCursor<'txn>,
@@ -590,9 +587,6 @@ impl<KC, DC, C, IM> fmt::Debug for RoRevPrefix<'_, KC, DC, C, IM> {
     }
 }
 
-#[cfg(feature = "read-txn-no-tls")]
-unsafe impl<KC, DC, IM> Send for RoRevPrefix<'_, KC, DC, IM> {}
-
 /// A reverse read-write prefix iterator structure.
 pub struct RwRevPrefix<'txn, KC, DC, C = DefaultComparator, IM = MoveThroughDuplicateValues> {
     cursor: RwCursor<'txn>,
