@@ -1,6 +1,12 @@
 use bitflags::bitflags;
+#[cfg(master3)]
+use lmdb_master3_sys as ffi;
+#[cfg(not(master3))]
 use lmdb_master_sys as ffi;
 
+#[allow(unused)] // for cargo auto doc links
+use crate::{Database, IntegerComparator};
+
 bitflags! {
     /// LMDB environment flags (see <http://www.lmdb.tech/doc/group__mdb__env.html> for more details).
     #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
@@ -8,11 +14,13 @@ bitflags! {
     #[repr(transparent)]
     pub struct EnvFlags: u32 {
         /// mmap at a fixed address (experimental).
-        const FIXEDMAP = ffi::MDB_FIXEDMAP;
+        const FIXED_MAP = ffi::MDB_FIXEDMAP;
         /// No environment directory.
         const NO_SUB_DIR = ffi::MDB_NOSUBDIR;
         /// Don't fsync after commit.
         const NO_SYNC = ffi::MDB_NOSYNC;
+        /// Open the previous transaction.
+        const PREV_SNAPSHOT = ffi::MDB_PREVSNAPSHOT;
         /// Read only.
         const READ_ONLY = ffi::MDB_RDONLY;
         /// Don't fsync metapage after commit.
@@ -22,6 +30,9 @@ bitflags! {
         /// Use asynchronous msync when MDB_WRITEMAP is used.
         const MAP_ASYNC = ffi::MDB_MAPASYNC;
         /// Tie reader locktable slots to MDB_txn objects instead of to threads.
+        // Note to self: When removing this flag from here, we must introduce an
+        //               internal-only AllEnvFlags akin to the AllDatabaseFlags bitflags.
+        #[deprecated(since="0.22.0", note="please use `EnvOpenOptions::read_txn_with_tls` or `EnvOpenOptions::read_txn_without_tls` instead")]
         const NO_TLS = ffi::MDB_NOTLS;
         /// Don't do any locking, caller must manage their own locks.
         const NO_LOCK = ffi::MDB_NOLOCK;
@@ -43,12 +54,15 @@ bitflags! {
         const DUP_SORT = ffi::MDB_DUPSORT;
         /// Numeric keys in native byte order: either `u32` or `usize`.
         /// The keys must all be of the same size.
+        ///
+        /// It is recommended to set the comparator to [`IntegerComparator`](crate::IntegerComparator),
+        /// rather than setting this flag manually.
         const INTEGER_KEY = ffi::MDB_INTEGERKEY;
         /// With [`DatabaseFlags::DUP_SORT`], sorted dup items have fixed size.
         const DUP_FIXED = ffi::MDB_DUPFIXED;
-        /// With [`DatabaseKey::DUP_SORT`], dups are [`DatabaseKey::INTEGER_KEY`]-style integers.
+        /// With [`DatabaseFlags::DUP_SORT`], dups are [`DatabaseFlags::INTEGER_KEY`]-style integers.
         const INTEGER_DUP = ffi::MDB_INTEGERDUP;
-        /// With [`DatabaseKey::DUP_SORT`], use reverse string dups.
+        /// With [`DatabaseFlags::DUP_SORT`], use reverse string dups.
         const REVERSE_DUP = ffi::MDB_REVERSEDUP;
         /// Create DB if not already existing.
         const CREATE = ffi::MDB_CREATE;
@@ -89,10 +103,10 @@ bitflags! {
         /// # db.clear(&mut wtxn)?;
         /// db.put(&mut wtxn, &"bonjour", &())?;
         /// db.put(&mut wtxn, &"hello", &())?;
-        /// db.put(&mut wtxn, &"holla", &())?;
+        /// db.put(&mut wtxn, &"hola", &())?;
         ///
         /// let mut iter = db.iter(&wtxn)?;
-        /// assert_eq!(iter.next().transpose()?, Some(("holla", ())));
+        /// assert_eq!(iter.next().transpose()?, Some(("hola", ())));
         /// assert_eq!(iter.next().transpose()?, Some(("hello", ())));
         /// assert_eq!(iter.next().transpose()?, Some(("bonjour", ())));
         /// assert_eq!(iter.next().transpose()?, None);
@@ -101,7 +115,7 @@ bitflags! {
         /// let mut iter = db.rev_iter(&wtxn)?;
         /// assert_eq!(iter.next().transpose()?, Some(("bonjour", ())));
         /// assert_eq!(iter.next().transpose()?, Some(("hello", ())));
-        /// assert_eq!(iter.next().transpose()?, Some(("holla", ())));
+        /// assert_eq!(iter.next().transpose()?, Some(("hola", ())));
         /// assert_eq!(iter.next().transpose()?, None);
         /// drop(iter);
         ///
@@ -172,6 +186,11 @@ bitflags! {
         /// Numeric keys in native byte order: either `u32` or `usize`.
         /// The keys must all be of the same size.
         ///
+        /// It is recommended to use the [`IntegerComparator`] when
+        /// opening the [`Database`] instead. This comparator provides
+        /// better support for ranges and does not allow for prefix
+        /// iteration, as it is not applicable in this context.
+        ///
         /// ```
         /// # use std::fs;
         /// # use std::path::Path;
@@ -214,6 +233,7 @@ bitflags! {
         /// wtxn.commit()?;
         /// # Ok(()) }
         /// ```
+        #[deprecated(since="0.21.0", note="prefer using `IntegerComparator` with the `DatabaseOpenOptions::key_comparator` method instead")]
         const INTEGER_KEY = ffi::MDB_INTEGERKEY;
         /// With [`DatabaseFlags::DUP_SORT`], sorted dup items have fixed size.
         ///
@@ -275,7 +295,7 @@ bitflags! {
         /// # Ok(()) }
         /// ```
         const DUP_FIXED = ffi::MDB_DUPFIXED;
-        /// With [`DatabaseKey::DUP_SORT`], dups are [`DatabaseKey::INTEGER_KEY`]-style integers.
+        /// With [`DatabaseFlags::DUP_SORT`], dups are [`DatabaseFlags::INTEGER_KEY`]-style integers.
         ///
         /// ```
         /// # use std::fs;
@@ -334,8 +354,9 @@ bitflags! {
         /// wtxn.commit()?;
         /// # Ok(()) }
         /// ```
+        #[deprecated(since="0.22.0", note="prefer using `IntegerComparator` with the `DatabaseOpenOptions::dup_sort_comparator` method instead")]
         const INTEGER_DUP = ffi::MDB_INTEGERDUP;
-        /// With [`DatabaseKey::DUP_SORT`], use reverse string dups.
+        /// With [`DatabaseFlags::DUP_SORT`], use reverse string dups.
         ///
         /// ```
         /// # use std::fs;
@@ -362,12 +383,12 @@ bitflags! {
         ///
         /// # db.clear(&mut wtxn)?;
         /// db.put(&mut wtxn, &68, &"bonjour")?;
-        /// db.put(&mut wtxn, &68, &"holla")?;
+        /// db.put(&mut wtxn, &68, &"hola")?;
         /// db.put(&mut wtxn, &68, &"hello")?;
         /// db.put(&mut wtxn, &92, &"hallo")?;
         ///
         /// let mut iter = db.get_duplicates(&wtxn, &68)?.expect("the key exists");
-        /// assert_eq!(iter.next().transpose()?, Some((68, "holla")));
+        /// assert_eq!(iter.next().transpose()?, Some((68, "hola")));
         /// assert_eq!(iter.next().transpose()?, Some((68, "hello")));
         /// assert_eq!(iter.next().transpose()?, Some((68, "bonjour")));
         /// assert_eq!(iter.next().transpose()?, None);
